==> deployit-java-client-3.6.3-sources.jar: com/xebialabs/deployit/client/DeploymentOptions.java <==
package com.xebialabs.deployit.client;

import java.io.Serializable;

public class DeploymentOptions implements Serializable {

	private boolean skipMode = false;
	private boolean testMode = false;

	private boolean importOnly = false;
	private boolean deletePreviouslyDeployedArtifact = false;

	//TODO: remove this option, since 3.6 the deployit server does not fail if the steps aren't generated anymore.
	private boolean failIfNoStepsAreGenerated = false;
	private boolean explicitMappings = false;
	private boolean generateDeployedOnUpgrade = false;
	private boolean cancelTaskOnError = true;

	public DeploymentOptions() {

	}

	public DeploymentOptions(boolean skipMode, boolean testMode, boolean importOnly, boolean deletePreviouslyDeployedArtifact, boolean failIfNoStepsAreGenerated, boolean explicitMappings, boolean generateDeployedOnUpgrade, boolean cancelTaskOnError) {
		this.skipMode = skipMode;
		this.testMode = testMode;
		this.importOnly = importOnly;
		this.deletePreviouslyDeployedArtifact = deletePreviouslyDeployedArtifact;
		this.failIfNoStepsAreGenerated = failIfNoStepsAreGenerated;
		this.explicitMappings = explicitMappings;
		this.generateDeployedOnUpgrade = generateDeployedOnUpgrade;
		this.cancelTaskOnError = cancelTaskOnError;
	}

	public boolean isSkipMode() {
		return skipMode;
	}

	public void setSkipMode(boolean skipMode) {
		this.skipMode = skipMode;
	}

	public boolean isTestMode() {
		return testMode;
	}

	public void setTestMode(boolean testMode) {
		this.testMode = testMode;
	}

	public boolean isImportOnly() {
		return importOnly;
	}

	public void setImportOnly(boolean importOnly) {
		this.importOnly = importOnly;
	}

	public boolean isDeletePreviouslyDeployedArtifact() {
		return deletePreviouslyDeployedArtifact;
	}

	public void setDeletePreviouslyDeployedArtifact(boolean deletePreviouslyDeployedArtifact) {
		this.deletePreviouslyDeployedArtifact = deletePreviouslyDeployedArtifact;
	}

	public boolean isFailIfNoStepsAreGenerated() {
		return failIfNoStepsAreGenerated;
	}

	public void setFailIfNoStepsAreGenerated(boolean failIfNoStepsAreGenerated) {
		this.failIfNoStepsAreGenerated = failIfNoStepsAreGenerated;
	}

	public boolean isExplicitMappings() {
		return explicitMappings;
	}

	public void setExplicitMappings(boolean explicitMappings) {
		this.explicitMappings = explicitMappings;
	}

	public boolean isGenerateDeployedOnUpgrade() {
		return generateDeployedOnUpgrade;
	}

	public void setGenerateDeployedOnUpgrade(boolean generateDeployedOnUpgrade) {
		this.generateDeployedOnUpgrade = generateDeployedOnUpgrade;
	}

	public boolean isCancelTaskOnError() {
		return cancelTaskOnError;
	}

	public void setCancelTaskOnError(boolean cancelTaskOnError) {
		this.cancelTaskOnError = cancelTaskOnError;
	}

	@Override
	public String toString() {
		return "DeploymentOptions{" +
				"cancelTaskOnError=" + cancelTaskOnError +
				", deletePreviouslyDeployedArtifact=" + deletePreviouslyDeployedArtifact +
				", explicitMappings=" + explicitMappings +
				", failIfNoStepsAreGenerated=" + failIfNoStepsAreGenerated +
				", generateDeployedOnUpgrade=" + generateDeployedOnUpgrade +
				", importOnly=" + importOnly +
				", skipMode=" + skipMode +
				", testMode=" + testMode +
				'}';
	}
}

==> deployit-java-client-3.7.0-sources.jar: com/xebialabs/deployit/client/DeploymentOptions.java <==
package com.xebialabs.deployit.client;

import java.io.Serializable;

public class DeploymentOptions implements Serializable {

	private boolean skipMode = false;
	private boolean testMode = false;

	private boolean importOnly = false;
	private boolean deletePreviouslyDeployedArtifact = false;

	//TODO: remove this option, since 3.6 the deployit server does not fail if the steps aren't generated anymore.
	private boolean failIfNoStepsAreGenerated = false;
	private boolean explicitMappings = false;
	private boolean generateDeployedOnUpgrade = false;
	private boolean cancelTaskOnError = true;

	private String orchestrator;

	public DeploymentOptions() {

	}

	public DeploymentOptions(boolean skipMode, boolean testMode, boolean importOnly, boolean deletePreviouslyDeployedArtifact, boolean failIfNoStepsAreGenerated, boolean explicitMappings, boolean generateDeployedOnUpgrade, boolean cancelTaskOnError, String orchestrator) {
		this.skipMode = skipMode;
		this.testMode = testMode;
		this.importOnly = importOnly;
		this.deletePreviouslyDeployedArtifact = deletePreviouslyDeployedArtifact;
		this.failIfNoStepsAreGenerated = failIfNoStepsAreGenerated;
		this.explicitMappings = explicitMappings;
		this.generateDeployedOnUpgrade = generateDeployedOnUpgrade;
		this.cancelTaskOnError = cancelTaskOnError;
		this.orchestrator = orchestrator;
	}

	public boolean isSkipMode() {
		return skipMode;
	}

	public void setSkipMode(boolean skipMode) {
		this.skipMode = skipMode;
	}

	public boolean isTestMode() {
		return testMode;
	}

	public void setTestMode(boolean testMode) {
		this.testMode = testMode;
	}

	public boolean isImportOnly() {
		return importOnly;
	}

	public void setImportOnly(boolean importOnly) {
		this.importOnly = importOnly;
	}

	public boolean isDeletePreviouslyDeployedArtifact() {
		return deletePreviouslyDeployedArtifact;
	}

	public void setDeletePreviouslyDeployedArtifact(boolean deletePreviouslyDeployedArtifact) {
		this.deletePreviouslyDeployedArtifact = deletePreviouslyDeployedArtifact;
	}

	public boolean isFailIfNoStepsAreGenerated() {
		return failIfNoStepsAreGenerated;
	}

	public void setFailIfNoStepsAreGenerated(boolean failIfNoStepsAreGenerated) {
		this.failIfNoStepsAreGenerated = failIfNoStepsAreGenerated;
	}

	public boolean isExplicitMappings() {
		return explicitMappings;
	}

	public void setExplicitMappings(boolean explicitMappings) {
		this.explicitMappings = explicitMappings;
	}

	public boolean isGenerateDeployedOnUpgrade() {
		return generateDeployedOnUpgrade;
	}

	public void setGenerateDeployedOnUpgrade(boolean generateDeployedOnUpgrade) {
		this.generateDeployedOnUpgrade = generateDeployedOnUpgrade;
	}

	public boolean isCancelTaskOnError() {
		return cancelTaskOnError;
	}

	public void setCancelTaskOnError(boolean cancelTaskOnError) {
		this.cancelTaskOnError = cancelTaskOnError;
	}

	public String getOrchestrator() {
		return orchestrator;
	}

	public void setOrchestrator(String orchestrator) {
		this.orchestrator = orchestrator;
	}

	@Override
	public String toString() {
		return "DeploymentOptions{" +
				"cancelTaskOnError=" + cancelTaskOnError +
				", deletePreviouslyDeployedArtifact=" + deletePreviouslyDeployedArtifact +
				", explicitMappings=" + explicitMappings +
				", failIfNoStepsAreGenerated=" + failIfNoStepsAreGenerated +
				", generateDeployedOnUpgrade=" + generateDeployedOnUpgrade +
				", importOnly=" + importOnly +
				", skipMode=" + skipMode +
				", testMode=" + testMode +
				", orchestrator=" + orchestrator +
				'}';
	}
}
